@@ -1,5 +1,5 @@
 <?php
-require("template-7.2c.inc.php");
+require ("template-7.2d.inc.php");
 $tpl = new Template();
 $tpl->set_file ("tp", "foobar.ihtml");
 $tpl->set_block("tp", "foo", "foo_parsed");
