@@ -73,11 +73,9 @@ switch (nvl($mode)) {
 			$frm["newmode"] = "insert";
 			$frm["submit_caption"] = "Add_Subcategory";
 			/* build the categories listbox options, preselect the selected item */
-//			$qid = new PGM_Sql;
 			$qid->begin();
 			build_category_tree(&$qid, &$category_options, $frm["parent"]);
 			$qid->commit();
-//			$qid->close();
 			include ("$CFG->dirroot" . "/form_header.php");
 			load_category_form_template($frm, $id, $category_options, $errors);
 		}
@@ -105,11 +103,9 @@ switch (nvl($mode)) {
 			$frm["newmode"] = "update";
 			$frm["submit_caption"] = "Save_Changes";
 			/* build the categories listbox options, preselect the selected item */
-//			$qid = new PGM_Sql;
 			$qid->begin();
 			build_category_tree(&$qid, &$category_options, $frm["parent"]);
 			$qid->commit();
-//			$qid->close();
 			include ("$CFG->dirroot" . "/form_header.php");
 			load_category_form_template($frm, $id, $category_options, $errors);
 		}
@@ -182,11 +178,9 @@ function print_add_category_form($id) {
 	$frm["submit_caption"] = "Add_Subcategory";
 
 	/* build the categories listbox options, preselect the selected item */
-//	$qid = new PGM_Sql;
 	$qid->begin();
 	build_category_tree(&$qid, &$category_options, $frm["parent"]);
 	$qid->commit();
-//	$qid->close();
 
 	load_category_form_template($frm, $id, $category_options, $errors);
 }
@@ -200,7 +194,6 @@ function print_edit_category_form($id) {
 	global $qid;
 
 	/* load up the information for the category */
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT name, special_level, description, parent_id
 		FROM categories
@@ -218,11 +211,9 @@ function print_edit_category_form($id) {
 	$frm["submit_caption"] = "Save_Changes";
 
 	/* build the categories listbox options, preselect the selected item */
-//	$qid = new PGM_Sql;
 	$qid->begin();
 	build_category_tree(&$qid, &$category_options, $frm["parent"]);
 	$qid->commit();
-//	$qid->close();
 
 	load_category_form_template($frm, $id, $category_options, $errors);
 }
@@ -237,7 +228,6 @@ function delete_category($id) {
 //	include ($CFG->globalerror);
 	global $qid;
 
-//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	/* find the parent of this category */
@@ -252,9 +242,6 @@ function delete_category($id) {
 	$cat->parent_id = $qid->f("parent_id");
 	$cat->parent = $qid->f("parent");
 
-	/* delete this category */
-	$qid->Query("DELETE FROM categories WHERE id = '$id'");
-
 	// delete products in this category that also belong
 	// to the parent category, to avoid duplicates forbidden
 	// by the primary key constraint
@@ -282,7 +269,6 @@ function delete_category($id) {
 	if (($numr = $qid->num_rows()) > 0) {
 		$toberemoved = "";
 		for ($i=0; $i<$numr-1; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$toberemoved .= "'" . $qid->f("product_id") . "', ";
 		}
@@ -308,12 +294,18 @@ function delete_category($id) {
 		WHERE parent_id = '$id'
 	");
 
+	/* delete this category from the categories table */
+	$qid->Query("DELETE FROM categories WHERE id = '$id'");
+
+	/* delete this category from the categories_i18n table */
+	$qid->Query("DELETE FROM categories_i18n WHERE category_id = '$id'");
+
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_deleted.ihtml"));
@@ -339,21 +331,26 @@ function insert_category($id, $frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-//	$qid = new PGM_Sql;
+	$qid->lock("categories");
 	$qid->Query("
 		INSERT INTO categories (parent_id, name, special_level, description)
 		VALUES ('$frm[parent]', '$frm[name]', '$frm[special_level]', '$frm[description]')
 	");
+	$qid->Query("SELECT id FROM categories ORDER BY id DESC");
+	$qid->next_record();
+	$inserted_category_id = $qid->f("id");
+	$qid->unlock();
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_added.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	$t->set_var(array(
+		"id"		=> $inserted_category_id,
 		"frm_name"	=> ov($frm[name]),
 		"backurl"	=> $backurl
 	));
@@ -372,7 +369,6 @@ function update_category($id, $frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE categories SET
 			 parent_id = '$frm[parent]'
@@ -383,15 +379,16 @@ function update_category($id, $frm) {
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/category_updated.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	include ("$CFG->localelangdir" . "/global-admin.inc.php");
 	$t->set_var(array(
+		"id"		=> $id,
 		"frm_name"	=> ov($frm[name]),
 		"backurl"	=> $backurl
 	));
@@ -404,11 +401,11 @@ function print_category_list() {
 
 	global $CFG, $ME;
 	global $SESSION;
-	global $page_number, $dbchanged;
+	global $page_number, $datachanged;
 //	include ($CFG->globalerror);
 	global $qid;
 
-	if (!isset($page_number) || $dbchanged) {
+	if (!isset($page_number) || $datachanged) {
 		$qid = new PGM_Sql;
 		$qid->Query("
 			SELECT cat.id, cat.name, cat.special_level, cat.description, parent.name AS parent
@@ -417,7 +414,6 @@ function print_category_list() {
 		");
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["categories"][$i]["id"] = $qid->f("id");
 			$SESSION["categories"][$i]["name"] = $qid->f("name");
@@ -501,7 +497,6 @@ function import_categories($HTTP_POST_FILES) {
 	global $qid;
 
 	/* Let's open a transaction */
-//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
@@ -528,7 +523,7 @@ function import_categories($HTTP_POST_FILES) {
 		} else {
 			/* ... otherwise let's save its ID ... */
 			$qid->next_record();
-			$pid = $qid->f("id");
+			$cid = $qid->f("id");
 
 			/* ... and let's see if the category already exists ... */
 			$qid->Query("SELECT id FROM categories WHERE name = '$fldarr[1]'");
@@ -536,7 +531,7 @@ function import_categories($HTTP_POST_FILES) {
 				/* ... if it doesn't exist let's create it ... */
 				$qid->Query("
 					INSERT INTO categories (parent_id, name, special_level, description)
-					VALUES ('$pid', '$fldarr[1]', '$fldarr[2]', '$fldarr[3]')
+					VALUES ('$cid', '$fldarr[1]', '$fldarr[2]', '$fldarr[3]')
 				");
 			} else {
 				/* ... otherwise let's save its ID ... */
@@ -545,7 +540,7 @@ function import_categories($HTTP_POST_FILES) {
 				/* ... and update ... */
 				$qid->Query("
 					UPDATE categories SET
-						parent_id = '$pid'
+						parent_id = '$cid'
 						,special_level = '$fldarr[2]'
 						,description = '$fldarr[3]'
 					WHERE id = '$sid'
@@ -559,9 +554,9 @@ function import_categories($HTTP_POST_FILES) {
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
