@@ -35,8 +35,6 @@ if (match_referer() && isset($HTTP_POST_VARS)) {
 	}
 }
 
-$qid->close();
-
 $DOC_TITLE = "Change_Password";
 include ("$CFG->dirroot" . "/header.php");
 include ("$CFG->dirroot" . "/form_header.php");
@@ -100,13 +98,11 @@ function password_valid($password, $username) {
 	global $SESSION;
 	
 	global $qid;
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT 1
 		FROM users
 		WHERE username = '$username' AND password = '$password'
 	");
-//	$qid->close();
 	return $qid->num_rows();
 }
 
@@ -116,7 +112,6 @@ function update_user_password($newpassword, $username) {
 	global $SESSION, $CFG;
 	global $qid;
 
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE users
 		SET password = '$newpassword'
@@ -124,7 +119,6 @@ function update_user_password($newpassword, $username) {
 	");
 	$qid->Query("SELECT priv FROM users WHERE username = '$username'");
 	$qid->next_record();
-//	$qid->close();
 
 	$appoggio = $qid->f("priv");
 	if ($appoggio == "admin") {
