@@ -1,7 +1,7 @@
-<?
+<?php
 /* (c) 2001 Marco Pratesi <pratesi@telug.it> */
 $t = new Template();
 $t->set_file(array("page" => "templates/footer.ihtml"));
-require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+include ("$CFG->localelangdir" . "/global-admin.inc.php");
 $t->pparse("out", "page");
 ?>
