@@ -1,4 +1,4 @@
-<?
+<?php
 /* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
  *
  * TERMS OF USAGE:
@@ -18,7 +18,7 @@
  * MAIN
  *****************************************************************************/
 
-include("../application.inc.php");
+include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
@@ -34,6 +34,6 @@ $t->set_var("cfg_myname", $CFG->myname);
 $t->pparse("out", "page");
 //include("templates/".$SESSION["lang"]."/index.ihtml");
 
-include("footer.php");
+include ("footer.php");
 
 ?>
