@@ -135,7 +135,6 @@ function print_edit_iva_form($id) {
 	global $qid;
 
 	/* load up the information for the iva percentage */
-//	$qid = new PGM_Sql;
 	$qid->Query("SELECT iva FROM iva WHERE id = '$id'");
 	$qid->next_record();
 	$frm["iva"] = $qid->f("iva");
@@ -156,7 +155,6 @@ function delete_iva($id) {
 //	include ($CFG->globalerror);
 	global $qid;
 
-//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	/* select the iva percentage to be deleted */
@@ -173,9 +171,9 @@ function delete_iva($id) {
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_deleted.ihtml"));
@@ -197,13 +195,12 @@ function insert_iva($frm) {
 //	include ($CFG->globalerror);
 	global $qid;
 
-//	$qid = new PGM_Sql;
 	$qid->Query("INSERT INTO iva (iva) VALUES ('$frm[iva]')");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_added.ihtml"));
@@ -225,13 +222,12 @@ function update_iva($id, $frm) {
 //	include ($CFG->globalerror);
 	global $qid;
 
-//	$qid = new PGM_Sql;
 	$qid->Query("UPDATE iva SET iva = '$frm[iva]' WHERE id = '$id'");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/iva_updated.ihtml"));
@@ -250,18 +246,16 @@ function print_iva_list() {
 
 	global $CFG, $ME;
 	global $SESSION;
-	global $page_number, $dbchanged;
+	global $page_number, $datachanged;
 //	include ($CFG->globalerror);
 	global $qid;
 
-	if (!isset($page_number) || $dbchanged) {
-//		$qid = new PGM_Sql;
+	if (!isset($page_number) || $datachanged) {
 		$qid->Query("
 			SELECT id, iva FROM iva WHERE id > 0 ORDER BY iva
 		");
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["iva"][$i]["id"] = $qid->f("id");
 			$SESSION["iva"][$i]["iva"] = $qid->f("iva");
@@ -338,7 +332,6 @@ function import_iva($HTTP_POST_FILES) {
 	$errors = new Object;
 	global $qid;
 
-//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
@@ -364,9 +357,9 @@ function import_iva($HTTP_POST_FILES) {
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
