@@ -142,7 +142,6 @@ function print_edit_order_state_form($id) {
 	global $qid;
 
 	/* load up the information for the order state */
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT name, description
 		FROM orders_states
@@ -169,7 +168,6 @@ function delete_order_state($id) {
 	global $qid;
 
 	if ($id > 0) {
-//		$qid = new PGM_Sql;
 		$qid->begin();
 
 		/* find out this order state name */
@@ -193,9 +191,9 @@ function delete_order_state($id) {
 		$qid->commit();
 
 		if (empty($SESSION["goback"]["query_string"]))
-			$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+			$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 		else
-			$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+			$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 		$t = new Template();
 		$t->set_file(array("page" => "templates/order_state_deleted.ihtml"));
@@ -222,16 +220,15 @@ function insert_order_state($frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		INSERT INTO orders_states (name, description)
 		VALUES ('$frm[name]', '$frm[description]')
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_state_added.ihtml"));
@@ -256,7 +253,6 @@ function update_order_state($id, $frm) {
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
 	}
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE orders_states SET
 			name = '$frm[name]'
@@ -265,9 +261,9 @@ function update_order_state($id, $frm) {
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_state_updated.ihtml"));
@@ -286,12 +282,11 @@ function print_order_state_list() {
 
 	global $CFG, $ME;
 	global $SESSION;
-	global $page_number, $dbchanged;
+	global $page_number, $datachanged;
 //	include ($CFG->globalerror);
 	global $qid;
 
-	if (!isset($page_number) || $dbchanged) {
-//		$qid = new PGM_Sql;
+	if (!isset($page_number) || $datachanged) {
 		$qid->Query("
 			SELECT id, name, description
 			FROM orders_states
@@ -300,7 +295,6 @@ function print_order_state_list() {
 		");
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["order_state"][$i]["id"] = $qid->f("id");
 			$SESSION["order_state"][$i]["name"] = $qid->f("name");
@@ -379,7 +373,6 @@ function import_orders_states($HTTP_POST_FILES) {
 	$errors = new Object;
 	global $qid;
 
-//	$qid = new PGM_Sql;
 	$qid->begin();
 
 	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
@@ -418,9 +411,9 @@ function import_orders_states($HTTP_POST_FILES) {
 
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
