@@ -22,6 +22,12 @@ include ("../application.inc.php");
 require_login();
 require_priv("admin");
 
+$qid = new PGM_Sql;
+$qid_order = new PGM_Sql;
+$qid_items = new PGM_Sql;
+$qid_user = new PGM_Sql;
+$qid_orders_states = new PGM_Sql;
+
 $DOC_TITLE = "Orders_Log_ca";
 include ("header.php");
 
@@ -66,8 +72,8 @@ function print_order_details($id) {
 	global $page_number;
 //	include ($CFG->globalerror);
 	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
+	global $qid_order, $qid_items, $qid_user;
 
-	$qid_order = new PGM_Sql;
 	$qid_order->Query("
 		SELECT o.*, os.name AS state_name
 		FROM ordersca o, orders_states os
@@ -75,10 +81,8 @@ function print_order_details($id) {
 	");
 	$qid_order->next_record();
 
-	$qid_items = new PGM_Sql;
 	get_order_items(&$qid_items, $id);
 
-	$qid_user= new PGM_Sql;
 	$order_username = $qid_order->f("username");
 	$qid_user->Query("
 		SELECT usertype, fiscalcode, email
@@ -138,8 +142,8 @@ function print_order_details($id) {
 			"prod_total"		=> $qid_items->f("total"),
 			"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
-		$appoggio = ov($qid_items->f("oiname"));
-		if ($qid_items->f("name") != $appoggio)
+		$appoggio = ($qid_items->f("lname") != "" && $qid_items->f("name") == $qid_items->f("oiname")) ? ov($qid_items->f("lname")) : ov($qid_items->f("oiname"));
+		if ($qid_items->f("name") != $qid_items->f("oiname"))
 			$appoggio = "<div class=\"warning\">" . $appoggio . "</div>";
 		if ($qid_items->f("name") != "")
 			$appoggio = "<a href=\"" . "$CFG->wwwroot" . "/admin/products.php?mode=details&product_id=" . $qid_items->f("product_id") . "\">" . $appoggio . "</a>";
@@ -178,6 +182,7 @@ function print_edit_order_form($id) {
 	global $page_number;
 //	include ($CFG->globalerror);
 	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
+	global $qid_order, $qid_items, $qid_user, $qid_orders_states;
 
 	$qid_order = new PGM_Sql;
 	$qid_order->Query("SELECT * FROM ordersca WHERE id = '$id'");
@@ -192,22 +197,18 @@ function print_edit_order_form($id) {
 	$frm["amount"] = $qid_order->f("amount");
 	$frm["delivery"] = $qid_order->f("delivery");
 	$frm["state_id"] = $qid_order->f("state_id");
-	$qid_orders_states = new PGM_Sql;
 	$qid_orders_states->Query("SELECT * FROM orders_states ORDER BY name");
 	$frm["order_state"] = array();
 	$numr = $qid_orders_states->num_rows();
 	$frm["num_orders_states"] = $numr;
 	for ($i=0; $i<$numr; $i++) {
-//		$qid_orders_states->seek($i);
 		$qid_orders_states->next_record();
 		$frm["order_state"][$i]["id"] = $qid_orders_states->f("id");
 		$frm["order_state"][$i]["name"] = $qid_orders_states->f("name");
 	}
 
-	$qid_items = new PGM_Sql;
 	get_order_items(&$qid_items, $id);
 
-	$qid_user = new PGM_Sql;
 	$qid_user->Query("
 		SELECT usertype, fiscalcode, email
 		FROM users
@@ -228,6 +229,10 @@ function print_edit_order_form($id) {
 		"frm_newmode"		=> $frm["newmode"],
 		"order_id"		=> ov($id),
 		"frm_date"		=> ov($frm["date"]),
+		"frm_year"		=> ov($frm["year"]),
+		"frm_month"		=> ov($frm["month"]),
+		"frm_day"		=> ov($frm["day"]),
+		"frm_weekday"		=> ov($frm["weekday"]),
 		"frm_username"		=> ov($frm["username"]),
 		"frm_amount"		=> $frm["amount"],
 		"frm_famount"		=> formatted_price($frm["amount"]),
@@ -280,8 +285,8 @@ function print_edit_order_form($id) {
 			"prod_total"		=> $qid_items->f("total"),
 			"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
-		$appoggio = ov($qid_items->f("oiname"));
-		if ($qid_items->f("name") != $appoggio)
+		$appoggio = ($qid_items->f("lname") != "" && $qid_items->f("name") == $qid_items->f("oiname")) ? ov($qid_items->f("lname")) : ov($qid_items->f("oiname"));
+		if ($qid_items->f("name") != $qid_items->f("oiname"))
 			$appoggio = "<div class=\"warning\">" . $appoggio . "</div>";
 		if ($qid_items->f("name") != "")
 			$appoggio = "<a href=\"" . "$CFG->wwwroot" . "/admin/products.php?mode=details&product_id=" . $qid_items->f("product_id") . "\">" . $appoggio . "</a>";
@@ -317,17 +322,17 @@ function delete_order($id) {
 	global $CFG, $ME;
 	global $SESSION;
 //	include ($CFG->globalerror);
+	global $qid;
 
-	$qid = new PGM_Sql;
 	$qid->begin();
 	$qid->Query("DELETE FROM ordersca WHERE id = '$id'");
 	$qid->Query("DELETE FROM order_items WHERE order_id = '$id'");
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_deleted.ihtml"));
@@ -343,8 +348,8 @@ function update_order($frm) {
 // update the order record in the database
 
 	global $CFG, $SESSION;
+	global $qid;
 
-	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE ordersca SET
 			 custinfo = '$frm[custinfo]'
@@ -355,9 +360,9 @@ function update_order($frm) {
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/order_updated.ihtml"));
@@ -376,13 +381,13 @@ function print_order_list() {
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-//	global $page_number, $dbchanged;
+//	global $page_number, $datachanged;
 	global $HTTP_GET_VARS;
 //	include ($CFG->globalerror);
 	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
+	global $qid;
 
-	if (!isset($HTTP_GET_VARS["page_number"]) || $HTTP_GET_VARS["dbchanged"]) {
-		$qid = new PGM_Sql;
+	if (!isset($HTTP_GET_VARS["page_number"]) || $HTTP_GET_VARS["datachanged"]) {
 		$qid->Query("
 			SELECT o.*, os.name AS state_name
 			FROM ordersca o, orders_states os
@@ -391,7 +396,6 @@ function print_order_list() {
   		");
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["ordersca"][$i]["id"] = $qid->f("id");
 			$SESSION["ordersca"][$i]["username"] = $qid->f("username");
