@@ -1,5 +1,4 @@
-<?
-
+<?php
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 $pages_links = "";
