@@ -117,8 +117,6 @@ switch (nvl($mode)) {
 		break;
 }
 
-$qid->close();
-
 include ("footer.php");
 
 /******************************************************************************
@@ -194,11 +192,10 @@ function load_product_form_template($frm, $category_options, $errors) {
 		$t->set_block("brand_used", "brand_used_option", "brand_used_options");
 		$t->set_var("brand_used_options", "");
 		for ($i=0; $i<$numr; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$t->set_var(array(
 				"frm_brand_id"		=> $qid->f("id"),
-				"frm_brand_selected"	=> $frm["brand_id"] == $qid->f("id") ? "selected" : "",
+				"frm_brand_selected"	=> ($frm["brand_id"] == $qid->f("id")) ? "selected" : "",
 				"frm_brand_name"	=> $qid->f("name")
 			));
 			$t->parse("brand_used_options", "brand_used_option", true);
@@ -215,11 +212,10 @@ function load_product_form_template($frm, $category_options, $errors) {
 		$t->set_block("iva_used", "iva_used_option", "iva_used_options");
 		$t->set_var("iva_used_options", "");
 		for ($i=0; $i<$numr; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$t->set_var(array(
 				"frm_iva_id"		=> $qid->f("id"),
-				"frm_iva_selected"	=> $frm["iva_id"] == $qid->f("id") ? "selected" : "",
+				"frm_iva_selected"	=> ($frm["iva_id"] == $qid->f("id")) ? "selected" : "",
 				"frm_iva_iva"		=> $qid->f("iva")
 			));
 			$t->parse("iva_used_options", "iva_used_option", true);
@@ -291,7 +287,6 @@ function print_product_details($product_id) {
 	$frm["categories"] = array();
 	$numr = $qid->num_rows();
 	for ($i=0; $i<$numr; $i++) {
-//		$qid->seek($i);
 		$qid->next_record();
 		$frm["categories"][] = $qid->f("category_id");
 	}
@@ -457,7 +452,6 @@ function print_edit_product_form($product_id) {
 	$frm["categories"] = array();
 	$numr = $qid->num_rows();
 	for ($i=0; $i<$numr; $i++) {
-//		$qid->seek($i);
 		$qid->next_record();
 		$frm["categories"][] = $qid->f("category_id");
 	}
@@ -514,12 +508,18 @@ function delete_product($product_id) {
 		WHERE product_id = '$product_id'
 	");
 
+	/* delete this product from the products_i18n table */
+	$qid->Query("
+		DELETE FROM products_i18n
+		WHERE product_id = '$product_id'
+	");
+
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/product_deleted.ihtml"));
@@ -643,16 +643,16 @@ function insert_product($frm, $HTTP_POST_FILES) {
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/product_added.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
 	$t->set_var(array(
-		"frm_product_id"	=> $inserted_product_id,
-		"backurl"		=> $backurl
+		"product_id"	=> $inserted_product_id,
+		"backurl"	=> $backurl
 	));
         $t->pparse("out", "page");
 }
@@ -684,13 +684,13 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 }
 */
 
-	if ($frm[delete_image]) {
+	if ($frm["delete_image"]) {
 		$upload_path = "$CFG->productsdir";
-		$upload_name = $upload_path . $frm[product_id];
+		$upload_name = $upload_path . $frm["product_id"];
 		$upload_name_thumb = $upload_name . ".thumb.jpg";
 		system ("rm -f $upload_name_thumb", $result);
-		$upload_name .= "." . $frm["old_imagetype"];
-		system ("rm -f $old_upload_name", $result);
+		$upload_name .= "." . $type;
+		system ("rm -f $upload_name", $result);
 		$imagewidth = "";
 		$imageheight = "";
 		$thumbwidth = "";
@@ -719,23 +719,29 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 		}
 		if ($newtype != "") {
 			$upload_path = "$CFG->productsdir";
-			$upload_name = $upload_path . $frm[product_id];
+			$upload_name = $upload_path . $frm["product_id"];
 			$upload_thumb_name = $upload_name . ".thumb.jpg";
+			$upload_name_old .= $upload_name . "." . $type;
 			$upload_name .= "." . $newtype;
-			$type = $newtype;
-			$imagewidth = $size[0];
-			$imageheight = $size[1];
-			system("$CFG->pnmpath/$convert " . $HTTP_POST_FILES['userfile']['tmp_name'] . " | " .
-				"$CFG->pnmpath/pnmscale -xysize 100 80 | " .
-				"$CFG->pnmpath/cjpeg -optimize -progressive -quality 85 > " .
-				$upload_thumb_name, $result);
-			$thumbsize = getimagesize ($upload_thumb_name);
-			$thumbwidth = $thumbsize[0];
-			$thumbheight = $thumbsize[1];
-			if (!copy($HTTP_POST_FILES['userfile']['tmp_name'], $upload_name))
+			if (!copy($HTTP_POST_FILES['userfile']['tmp_name'], $upload_name)) {
 				echo "<div class=warning>" . $image_upload_failed . "</div>";
-			else
+			} else {
 				system ("chmod 644 $upload_name", $result);
+// if we are updating a product image and the old imagetype
+// is empty or different from the new one, then we remove the old image
+				if ($newtype != $type)
+					system ("rm -f ".$upload_name_old, $result);
+				$type = $newtype;
+				$imagewidth = $size[0];
+				$imageheight = $size[1];
+				system("$CFG->pnmpath/$convert " . $HTTP_POST_FILES['userfile']['tmp_name'] . " | " .
+					"$CFG->pnmpath/pnmscale -xysize 100 80 | " .
+					"$CFG->pnmpath/cjpeg -optimize -progressive -quality 85 > " .
+					$upload_thumb_name, $result);
+				$thumbsize = getimagesize ($upload_thumb_name);
+				$thumbwidth = $thumbsize[0];
+				$thumbheight = $thumbsize[1];
+			}
 		}
 	}
 
@@ -792,9 +798,9 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 	$qid->commit();
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/product_updated.ihtml"));
@@ -813,23 +819,20 @@ function print_product_list() {
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-	global $page_number, $dbchanged;
+	global $page_number, $datachanged;
 //	include ($CFG->globalerror);
 	global $qid;
 
-	if (!isset($page_number) || $dbchanged) {
+	if (!isset($page_number) || $datachanged) {
 		$qid->Query("
 			SELECT
-				p.id AS product_id
+				 p.id AS product_id
 				,p.code
 				,p.name
 				,p.price
 				,p.discount
 				,p.discqty
 				,p.weight
-				,p.imagetype
-				,p.imagewidth
-				,p.imageheight
 				,p.thumbwidth
 				,p.thumbheight
 				,c.name AS category
@@ -839,7 +842,6 @@ function print_product_list() {
   		");
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["products"][$i]["product_id"] = $qid->f("product_id");
 			$SESSION["products"][$i]["code"] = $qid->f("code");
@@ -863,7 +865,7 @@ function print_product_list() {
 
 	if ($SESSION["numr"] > $SESSION["products_per_page"]) {
 		$first = ($page_number-1)*$SESSION["products_per_page"];
-		$last = $SESSION["numr"] < $page_number*$SESSION["products_per_page"] ? $SESSION["numr"]-1 : $page_number*$SESSION["products_per_page"]-1;
+		$last = ($SESSION["numr"] < $page_number*$SESSION["products_per_page"]) ? $SESSION["numr"]-1 : $page_number*$SESSION["products_per_page"]-1;
 		$num_pages = $SESSION["numr"] / $SESSION["products_per_page"];
 		if (!($num_pages == (integer) $num_pages)) {
 			$num_pages = (integer) $num_pages + 1;
@@ -1113,9 +1115,9 @@ function import_products($HTTP_POST_FILES) {
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
@@ -1238,9 +1240,9 @@ function import_images($HTTP_POST_FILES) {
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
