@@ -273,7 +273,7 @@ function print_add_user_form($usertype) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	global $page_number, $dbchanged;
+	global $page_number, $datachanged;
 //	include ($CFG->globalerror);
 
 	/* set default values for the reset of the fields */
@@ -304,7 +304,7 @@ function print_edit_user_form($username) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	global $page_number, $dbchanged;
+	global $page_number, $datachanged;
 //	include ($CFG->globalerror);
 	global $qid;
 
@@ -360,9 +360,9 @@ function delete_user($username) {
 		$qid->Query("DELETE FROM users WHERE username = '$username'");
 
 		if (empty($SESSION["goback"]["query_string"]))
-			$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+			$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 		else
-			$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+			$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 		$t = new Template();
 		$t->set_file(array("page" => "templates/user_deleted.ihtml"));
@@ -454,9 +454,9 @@ function insert_user($frm) {
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_added.ihtml"));
@@ -500,9 +500,9 @@ function update_user($frm) {
 	");
 
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 
 	$t = new Template();
 	$t->set_file(array("page" => "templates/user_updated.ihtml"));
@@ -522,11 +522,11 @@ function print_user_list() {
 	global $CFG, $ME;
 	global $SESSION;
 	global $yes;
-	global $page_number, $dbchanged;
+	global $page_number, $datachanged;
 //	include ($CFG->globalerror);
 	global $qid;
 
-	if (!isset($page_number) || $dbchanged) {
+	if (!isset($page_number) || $datachanged) {
 		$qid->Query("
 			SELECT username, firstname, lastname, phone, email, authdata, acceptadvert
 			FROM users
@@ -535,7 +535,6 @@ function print_user_list() {
 		");
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["users"][$i]["username"] = $qid->f("username");
 			$SESSION["users"][$i]["firstname"] = $qid->f("firstname");
@@ -737,9 +736,9 @@ function import_users($HTTP_POST_FILES) {
 	
 	/* The End */
 	if (empty($SESSION["goback"]["query_string"]))
-		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "?datachanged=1";
 	else
-		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+		$backurl = $SESSION["goback"]["request_uri"] . "&datachanged=1";
 	$t = new Template();
 	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
 	include ("$CFG->localelangdir" . "/global-common.inc.php");
