@@ -13,7 +13,7 @@ $SESSION["catbrowser_target"] = "bodyframe";
 
 <html>
 <frameset cols="180,*" framespacing=0 frameborder=no border=0>
-<frame name="categories" src="shopping/navigation.php?p=0" target="bodyframe">
+<frame name="categories" src="shopping/navigation.php" target="bodyframe">
 <frame name="bodyframe" src="<?php echo $REFERER_AND_QUERY; ?>">
 </frameset>
 </html>
