@@ -6,7 +6,7 @@ if ($SESSION["frames_used"]) {
 
 <html>
 <frameset cols="180,*" framespacing=0 frameborder=no border=0>
-<frame name="categories" src="shopping/navigation.php?p=0" target="bodyframe">
+<frame name="categories" src="shopping/navigation.php" target="bodyframe">
 <frame name="bodyframe" src="<?php echo "$CFG->firstpage"; ?>">
 </frameset>
 </html>
