@@ -1,7 +1,7 @@
-<!-- PHP Layers Menu 1.0.0 (c) 2001 Marco Pratesi <pratesi@telug.it> -->
+<!-- PHP Layers Menu 1.0.1 (c) 2001 Marco Pratesi <pratesi@telug.it> -->
 
 <?php
-for ($cnt=1; $cnt<count($tree); $cnt++)
+for ($cnt=1; $cnt<=count($tree); $cnt++)
 	if (!($tree[$cnt+1][0]<=$tree[$cnt][0])) {
 $cellpadding = 10;
 $width = $abscissa_step - $cellpadding;
@@ -39,4 +39,4 @@ loaded = 1;	// to avoid stupid errors of Microsoft browsers
 // -->
 </script>
 
-<!-- PHP Layers Menu 1.0.0 (c) 2001 Marco Pratesi <pratesi@telug.it> -->
+<!-- PHP Layers Menu 1.0.1 (c) 2001 Marco Pratesi <pratesi@telug.it> -->
