@@ -100,37 +100,6 @@ function has_priv($priv) {
 	return $SESSION["user"]["priv"] == $priv;
 }
 
-function build_category_path(&$qid, $id=1, &$category_path) {
-// puts in $category_path the path of the product categories,
-// starting from the category specified by $id and ending with the top
-
-	global $CFG;
-
-//	$qid = new PGM_Sql;
-
-	while ($id > 1) {
-		$qid->Query("
-			SELECT parent_id, name
-			FROM categories
-			WHERE id = '$id'
-		");
-		if ($qid->num_rows()) {
-			$qid->next_record();
-			$parent = $qid->f("parent_id");
-			$name = $qid->f("name");
-			$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
-			$category_path = " &gt; " . $name . $category_path;
-		} else {
-			$parent = 1;
-			$name = "";
-		}
-		$id = $parent;
-	}
-	$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>" . $category_path;
-
-//	$qid->close();
-}
-
 function generate_password($maxlen=10) {
 /* returns a randomly generated password of length $maxlen.  inspired by
  * http://www.phpbuilder.com/columns/jesus19990502.php3 */
@@ -219,28 +188,10 @@ function reset_user_password(&$qid, $username) {
 	);
 
 	$qid->commit();
-//	$qid->close();
 
 	return 0;
 }
 
-function get_cart_items(&$qid) {
-/* return a $qid of all the items in the shopping cart */
-
-	global $SESSION, $CART;
-
-	$in_clause = $CART->get_productid_list();
-	if (empty($in_clause)) {
-		return false;
-	}
-
-	$qid->Query("
-		SELECT p.*, i.iva
-		FROM products p, iva i
-		WHERE p.iva_id = i.id AND p.id IN ($in_clause)
-	");
-}
-
 //function chop_ccnum($ccnum) {
 ///* this function returns the the first and last 4 digits of the credit card number
 // * and the expiry date.  it is mainly used when we want to display the credit
@@ -292,10 +243,6 @@ function clear_orderinfo() {
 	unset($SESSION["orderinfo"]);
 }
 
-function star() {
-	echo "<font color=\"#ff0000\">*</font>";
-}
-
 function return_star() {
 	return "<font color=\"#ff0000\">*</font>";
 }
@@ -598,7 +545,7 @@ function validate_country($country, &$errors, &$msg) {
 	}
 }
 
-function validate_zip_code($zip_code, &$errors, &$msg) {
+function validate_zip_code($zip_code, &$errors, &$msg, $length=5) {
 
 	global $CFG, $SESSION;
 	include ($CFG->globalerror);
@@ -612,10 +559,13 @@ function validate_zip_code($zip_code, &$errors, &$msg) {
 	} else if ($zip_code <= 0) {
 		$errors->zip_code = true;
 		$msg .= "<li>".$zip_code_is_zero;
-	} else if (strlen($zip_code) <> $SESSION["zip_code_length"]) {
+	} else if (strlen($zip_code) > $SESSION["zip_code_length"]) {
 		$errors->zip_code = true;
-		$msg .= "<li>".$zip_code_length_is_wrong;
-	}
+		$msg .= "<li>".$zip_code_length_too_long;
+	} /* else if ($length != 0 && strlen($zip_code) <> $length) {
+		$errors->zip_code = true;
+		$msg .= "<li>".$zip_code_length_is_wrong.$length;
+	} */
 }
 
 function validate_phone($phone, &$errors, &$msg) {
@@ -795,6 +745,32 @@ function validate_comments($comments, &$errors, &$msg) {
 	}
 }
 
+function validate_lang(&$qid, $lang, &$errors, &$msg) {
+
+	global $CFG, $SESSION;
+	include ($CFG->globalerror);
+
+	if ($lang == "") {
+		$errors->lang = true;
+		$msg .= "<li>".$empty_lang;
+	} else if (strlen($lang) > $SESSION["lang_length"]) {
+		$errors->lang = true;
+		$msg .= "<li>".$lang_too_long;
+	} else {
+		// according to glibc locales...
+		eregi ("^[a-zA-Z0-9\.\_\@]{1,}", $lang, $matched_lang);
+		if ($lang != $matched_lang[0]) {
+			$errors->lang = true;
+			$msg .= "<li>".$not_valid_lang;
+		}
+		$qid->Query("SELECT lang FROM languages WHERE lang = '$lang'");
+		if ($qid->num_rows() > 0) {
+			$errors->lang = true;
+			$msg .= "<li>".$the_lang.$lang.$already_exists;
+		}
+	}
+}
+
 function validate_category_name($category_name, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
@@ -849,6 +825,50 @@ function validate_brand_description($brand_description, &$errors, &$msg) {
 	}
 }
 
+function validate_iva($iva, &$errors, &$msg) {
+
+	global $CFG;
+	include ($CFG->globalerror);
+
+	if ($iva != "") {
+		eregi ("[0-9]{0,}[.]{0,1}[0-9]{0,}", $iva, $matched_iva);
+		if ($iva != $matched_iva[0] || $iva == ".") {
+			$errors->iva = true;
+			$msg .= "<li>".$not_valid_iva;
+		} else if ($iva < 0 || $iva > 100) {
+			$errors->iva = true;
+			$msg .= "<li>".$iva_not_between_0_and_100;
+		}
+	}
+}
+
+function validate_color_name($color_name, &$errors, &$msg) {
+
+	global $CFG, $SESSION;
+	include ($CFG->globalerror);
+
+	$stripped_color_name = str_replace(" ", "", $color_name);
+
+	if ($color_name == "" || $stripped_color_name == "") {
+		$errors->color_name = true;
+		$msg .= "<li>".$empty_color_name;
+	} else if (strlen($color_name) > $SESSION["color_name_length"]) {
+		$errors->color_name = true;
+		$msg .= "<li>".$SESSION["color_name_length"];
+	}
+}
+
+function validate_color_description($color_description, &$errors, &$msg) {
+
+	global $CFG, $SESSION;
+	include ($CFG->globalerror);
+
+	if (strlen($color_description) > $SESSION["color_description_length"]) {
+		$errors->color_description = true;
+		$msg .= "<li>".$color_description_too_long;
+	}
+}
+
 function validate_product_code($product_code, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
@@ -930,23 +950,6 @@ function validate_price($price, &$errors, &$msg) {
 	}
 }
 
-function validate_iva($iva, &$errors, &$msg) {
-
-	global $CFG;
-	include ($CFG->globalerror);
-
-	if ($iva != "") {
-		eregi ("[0-9]{0,}[.]{0,1}[0-9]{0,}", $iva, $matched_iva);
-		if ($iva != $matched_iva[0] || $iva == ".") {
-			$errors->iva = true;
-			$msg .= "<li>".$not_valid_iva;
-		} else if ($iva < 0 || $iva > 100) {
-			$errors->iva = true;
-			$msg .= "<li>".$iva_not_between_0_and_100;
-		}
-	}
-}
-
 function validate_discount($discount, $discqty, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
@@ -981,59 +984,6 @@ function validate_discount($discount, $discqty, &$errors, &$msg) {
 	}
 }
 
-function validate_order_state_name($order_state_name, &$errors, &$msg) {
-
-	global $CFG, $SESSION;
-	include ($CFG->globalerror);
-
-	$stripped_order_state_name = str_replace(" ", "", $order_state_name);
-
-	if ($order_state_name == "" || $stripped_order_state_name == "") {
-		$errors->order_state_name = true;
-		$msg .= "<li>".$empty_order_state_name;
-	} else if (strlen($order_state_name) > $SESSION["order_state_name_length"]) {
-		$errors->order_state_name = true;
-		$msg .= "<li>".$order_state_name_too_long;
-	}
-}
-
-function validate_order_state_description($order_state_description, &$errors, &$msg) {
-
-	global $CFG, $SESSION;
-	include ($CFG->globalerror);
-
-	if (strlen($order_state_description) > $SESSION["order_state_description_length"]) {
-		$errors->order_state_description = true;
-		$msg .= "<li>".$order_state_description_too_long;
-	}
-}
-
-function validate_searched_discount($discount, &$errors, &$msg) {
-
-	eregi ("[0-9]{0,}[.]{0,1}[0-9]{0,}", $discount, $matched_discount);
-	if ($discount != $matched_discount[0] || $discount == ".") {
-		$errors->discount = true;
-		$msg .= "<li>".$not_valid_discount;
-	} else if ($discount < 0 || $discount > 100) {
-		$errors->discount = true;
-		$msg .= "<li>".$discount_not_between_0_and_100;
-	}
-}
-
-function validate_searched_discqty($discqty, &$errors, &$msg) {
-
-	if ($discqty != "" && ((string) ((int) $discqty) != "$discqty")) {
-		$errors->discqty = true;
-		$msg .= "<li>".$discqty_notint;
-	} else if ($discqty < 0) {
-		$errors->discqty = true;
-		$msg .= "<li>".$discqty_is_negative;
-	} else if ($discqty > $SESSION["discqtymax"]) {
-		$errors->discqty = true;
-		$msg .= "<li>".$discqty_is_too_large;
-	}
-}
-
 function validate_weight($weight, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
@@ -1097,6 +1047,59 @@ function validate_product_extended_description($product_extended_description, &$
 	}
 }
 
+function validate_order_state_name($order_state_name, &$errors, &$msg) {
+
+	global $CFG, $SESSION;
+	include ($CFG->globalerror);
+
+	$stripped_order_state_name = str_replace(" ", "", $order_state_name);
+
+	if ($order_state_name == "" || $stripped_order_state_name == "") {
+		$errors->order_state_name = true;
+		$msg .= "<li>".$empty_order_state_name;
+	} else if (strlen($order_state_name) > $SESSION["order_state_name_length"]) {
+		$errors->order_state_name = true;
+		$msg .= "<li>".$order_state_name_too_long;
+	}
+}
+
+function validate_order_state_description($order_state_description, &$errors, &$msg) {
+
+	global $CFG, $SESSION;
+	include ($CFG->globalerror);
+
+	if (strlen($order_state_description) > $SESSION["order_state_description_length"]) {
+		$errors->order_state_description = true;
+		$msg .= "<li>".$order_state_description_too_long;
+	}
+}
+
+function validate_searched_discount($discount, &$errors, &$msg) {
+
+	eregi ("[0-9]{0,}[.]{0,1}[0-9]{0,}", $discount, $matched_discount);
+	if ($discount != $matched_discount[0] || $discount == ".") {
+		$errors->discount = true;
+		$msg .= "<li>".$not_valid_discount;
+	} else if ($discount < 0 || $discount > 100) {
+		$errors->discount = true;
+		$msg .= "<li>".$discount_not_between_0_and_100;
+	}
+}
+
+function validate_searched_discqty($discqty, &$errors, &$msg) {
+
+	if ($discqty != "" && ((string) ((int) $discqty) != "$discqty")) {
+		$errors->discqty = true;
+		$msg .= "<li>".$discqty_notint;
+	} else if ($discqty < 0) {
+		$errors->discqty = true;
+		$msg .= "<li>".$discqty_is_negative;
+	} else if ($discqty > $SESSION["discqtymax"]) {
+		$errors->discqty = true;
+		$msg .= "<li>".$discqty_is_too_large;
+	}
+}
+
 function validate_priv($priv, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
