@@ -1,15 +1,14 @@
-<?
+<?php
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2001 Fabio Molinari <fabio.m@mclink.it> */
 
 $REFERER = get_referer();
 $REFERER_AND_QUERY = get_full_referer();
 if (!strpos($REFERER_AND_QUERY, "from_menu=yes") && !strpos($REFERER_AND_QUERY, "search")) {
-	if ($REFERER == $REFERER_AND_QUERY) {
+	if ($REFERER == $REFERER_AND_QUERY)
 		$REFERER_AND_QUERY = $REFERER . "?from_menu=yes";
-	} else {
+	else
 		$REFERER_AND_QUERY = $REFERER_AND_QUERY . "&from_menu=yes";
-	}
 }
 
 ?>
