@@ -105,6 +105,7 @@ $t->set_var(array(
 "Credit_Card" => "Carta di Credito",
 "Comments_and_Special_Instructions" => "Commenti / Istruzioni speciali",
 "Qty" => "Q.t&agrave;",
+"Quantity" => "Quantit&agrave;",
 "Sub_Total" => "Sub Totale",
 "Delivery" => "Spedizione",
 "Purchase_Now" => "Acquista ora",
@@ -129,6 +130,9 @@ $t->set_var(array(
 "Brand" => "Marca",
 "Brands" => "Marche",
 "The_brand" => "La marca",
+"Color" => "Colore",
+"Colors" => "Colori",
+"The_color" => "Il colore",
 "User" => "Utente",
 "Username" => "Username",
 "Min_Username_Length" => "(min. ". $SESSION["username_length_min"] . " caratteri)",
