@@ -8,9 +8,10 @@ $t->set_var(array(
 
 "Product_not_found" => "Prodotto non trovato",
 "Sorry_product_not_found" => "Spiacente, il prodotto cercato non &egrave; stato trovato.  Sei pregato di cercare <a href=\"" . "$CFG->wwwroot" . "/shopping/\">nel nostro catalogo</a> per trovare quello che cerchi.",
-"Add_to_cart" => "+ Aggiungi al carrello",
+"Add_to_cart" => "Aggiungi al carrello",
 "Add_to_Shopping_Cart" => "+ Aggiungi al carrello della spesa",
 "In_the_cart" => "Nel carrello",
+"Items_in_the_cart" => "Pezzi nel carrello",
 "Categories_Browsing" => "Navigazione delle Categorie",
 "Your_shopping_cart_is_empty" => "Il tuo carrello &egrave; vuoto, <a href=\"" . "$CFG->wwwroot" . "/shopping/\">consulta il catalogo dei prodotti</a>.",
 "Step_1_Enter_Billing_Information" => "Passo 1. Inserisci le informazioni per l'acquisto",
