@@ -1,4 +1,4 @@
-<?
+<?php
 
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 /* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
