@@ -105,6 +105,7 @@ $t->set_var(array(
 "Credit_Card" => "Credit Card",
 "Comments_and_Special_Instructions" => "Comments / Special Instructions",
 "Qty" => "Qty",
+"Quantity" => "Quantity",
 "Sub_Total" => "Sub Total",
 "Delivery" => "Delivery",
 "Purchase_Now" => "Purchase Now",
@@ -129,6 +130,9 @@ $t->set_var(array(
 "Brand" => "Brand",
 "Brands" => "Brands",
 "The_brand" => "The brand",
+"Color" => "Color",
+"Colors" => "Colors",
+"The_color" => "The color",
 "User" => "User",
 "Username" => "Username",
 "Min_Username_Length" => "(at least ". $SESSION["username_length_min"] . " characters)",
