@@ -28,39 +28,13 @@ include ("$CFG->dirroot" . "/header.php");
 setdefault(&$id, 1);
 $qid_bcp = new PGM_Sql;
 build_category_path(&$qid_bcp, $id, $category_path);
-$qid_bcp->close();
 
 /* get the name and description of all the sub-categories under this one */
 $qid_c = new PGM_Sql;
-$qid_c->Query("
-	SELECT id, name, special_level, description
-	FROM categories
-	WHERE parent_id = '$id' AND id > 1
-	ORDER BY special_level, name
-");
+get_subcategories(&$qid_c, $id);
 /* get all the products under this category */
 $qid_p = new PGM_Sql;
-$qid_p->Query("
-	SELECT
-		 p.id
-		,p.code
-		,p.name AS name
-		,p.price
-		,p.discount
-		,p.discqty
-		,p.weight
-		,p.special_flag
-		,p.special_level
-		,p.description
-		,p.thumbwidth
-		,p.thumbheight
-		,pc.category_id
-		,b.name AS bname
-		,i.iva
-	FROM products p, products_categories pc, brands b, iva i
-	WHERE p.id = pc.product_id AND p.brand_id = b.id AND p.iva_id = i.id AND pc.category_id = '$id'
-	ORDER BY p.special_level ASC
-	");
+get_products_under_category(&$qid_p, $id);
 
 $t = new Template();
 $t->set_file(array("page" => "templates/index.ihtml"));
@@ -89,17 +63,18 @@ if (!$SESSION["frames_used"] || has_priv("admin")){
 		$t->parse("no_sub_categories_blck", "no_sub_categories", true);
 	else {
 		while ($qid_c->next_record()) {
+			$appoggio = ($qid_c->f("lname") != "") ? $qid_c->f("lname") : $qid_c->f("name");
 			if (has_priv("admin")) {
 				$t->set_var(array(
 					"c_special_level"	=> $qid_c->f("special_level") . " - ",
 					"category_id"		=> $qid_c->f("id"),
-					"cname"			=> ov($qid_c->f("name"))
+					"cname"			=> ov($appoggio)
 				));
 			} else {
 				$t->set_var(array(
 					"c_special_level"	=> "",
 					"category_id"		=> $qid_c->f("id"),
-					"cname"			=> ov($qid_c->f("name"))
+					"cname"			=> ov($appoggio)
 				));
 			}
 			$t->parse("category_rows", "category_row", true);
@@ -149,14 +124,15 @@ else {
 		$t->set_var("weight_used_blck", "");
 // ... now we have reset all nested blocks :)
 		$appoggio = $CART->productitemcount($qid_p->f("id"));
+		$appoggio = ($appoggio == "") ? 0 : $appoggio;
 		$t->set_var(array(
 			"id"		=> $id,
 			"product_id"	=> $qid_p->f("id"),
 			"product_code"	=> $qid_p->f("code"),
-			"pname"		=> ov($qid_p->f("name")),
+			"pname"		=> ($qid_p->f("lname") != "") ? ov($qid_p->f("lname")) : ov($qid_p->f("name")),
 			"price"		=> price,
 			"fprice"	=> formatted_price($qid_p->f("price")),
-			"description"	=> ovwbr($qid_p->f("description")),
+			"description"	=> ($qid_p->f("ldescription") != "") ? ovwbr($qid_p->f("ldescription")) : ovwbr($qid_p->f("description")),
 			"productitemcount"	=> $appoggio
 		));
 		if (has_priv("admin")) {
