@@ -15,7 +15,7 @@ include ("$CFG->localelangdir" . "/global-common.inc.php");
 
 <table>
 <tr>
-<td class="label"><?php echo $t->get_var("Categories"); ?>:</td>
+<td class="label"><a href="<?php echo "$CFG->wwwroot"; ?>/shopping/" target="bodyframe"><?php echo $t->get_var("Shopping"); ?></a></td>
 </tr>
 <tr valign="top">
 <td class="normal">
@@ -25,8 +25,6 @@ $qid_bc = new PGM_Sql;
 $qid_bc->begin();
 build_catbrowser(&$qid_bc, $categories);
 $qid_bc->commit();
-$qid_bc->close();
-$categories = ".Top^" . "$CFG->wwwroot" . "/shopping/^" . $SESSION["catbrowser_target"] . "\n" . $categories;
 require ("$CFG->libdir" . "/treemenu.inc.php");
 ?>
 
