@@ -44,24 +44,7 @@ if (!empty($product_id)) {
 	die;
 }
 
-$qid->Query("
-	SELECT
-		 p.id AS product_id
-		,p.code
-		,p.name AS name
-		,p.price
-		,p.discount
-		,p.discqty
-		,p.weight
-		,p.extended_description
-		,p.imagetype
-		,p.imagewidth
-		,p.imageheight
-		,b.name AS bname
-		,i.iva
-	FROM products p, brands b, iva i
-	WHERE p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
-");
+get_products_details(&$qid, $product_id);
 
 if ($qid->num_rows() > 0) {
 	$qid->next_record();
@@ -85,7 +68,6 @@ $t->set_var(array("noproduct_blck" => ""));
 if ($prod) {
 	$qid_bcp = new PGM_Sql;
 	build_category_path(&$qid_bcp, $id, $category_path);
-	$qid_bcp->close();
 	$t->set_var("category_path", $category_path);
 
 	$t->set_block("product", "brand_used", "brand_used_blck");
@@ -103,14 +85,15 @@ if ($prod) {
 	$t->set_block("product", "notadminprodimage", "notadminprodimage_blck");
 	$t->set_var("notadminprodimage_blck", "");
 	$appoggio = $CART->productitemcount($qid->f("product_id"));
+	$appoggio = ($appoggio == "") ? 0 : $appoggio;
 	$t->set_var(array(
 		"category_id"		=> $id,
 		"product_id"		=> $qid->f("product_id"),
 		"product_code"		=> $qid->f("code"),
-		"name"			=> ov($qid->f("name")),
+		"name"			=> ($qid->f("lname") != "") ? ov($qid->f("lname")) : ov($qid->f("name")),
 		"price"			=> $qid->f("price"),
 		"fprice"		=> formatted_price($qid->f("price")),
-		"extended_description"	=> ovwbr($qid->f("extended_description")),
+		"extended_description"	=> ($qid->f("lextended_description") != "") ? ovwbr($qid->f("lextended_description")) : ovwbr($qid->f("extended_description")),
 		"imagetype"		=> $qid->f("imagetype"),
 		"productitemcount"	=> $appoggio
 	));
