@@ -20,11 +20,14 @@
 
 include ("../application.inc.php");
 
-$CART->add($product_id, 1);
-$CART->cleanup();
-$qid_crt = new PGM_Sql;
-$CART->recalc_total(&$qid_crt);
-$qid_crt->close();
+if (empty($quantity)) $quantity = 1;
+else $quantity = intval($quantity);
+if ($quantity > 0) { // && $quantity < 1000) {
+	$CART->add($product_id, $quantity);
+	$CART->cleanup();
+	$qid_crt = new PGM_Sql;
+	$CART->recalc_total(&$qid_crt);
+}
 
 if (! empty($HTTP_REFERER))
 	header("Location: $HTTP_REFERER");
