@@ -2,7 +2,7 @@
 /* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 include ("application.inc.php");
 $SESSION["lang"] = "us";
-require ("$CFG->libdir" . "/referer_and_query.inc.php");
+require ("$CFG->libdir" . "/referer_and_query_lang.inc.php");
 if ($SESSION["frames_used"]) { ?>
 
 <script language="JavaScript">
