@@ -34,8 +34,6 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 	}
 }
 
-$qid->close();
-
 $DOC_TITLE = "Change_Password";
 
 include ("$CFG->dirroot" . "/header.php");
@@ -98,17 +96,14 @@ function password_valid($password) {
 /* return true if the user's password is valid */
 
 	global $SESSION;
+	global $qid;
 	
 	$username = $SESSION["user"]["username"];
-
-	global $qid;
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		SELECT 1
 		FROM users
 		WHERE username = '$username' AND password = '$password'
 	");
-//	$qid->close();
 	return $qid->num_rows();
 }
 
@@ -116,17 +111,14 @@ function update_password($newpassword) {
 /* set the user's password to the new one */
 
 	global $SESSION, $CFG;
+	global $qid;
 	
 	$username = $SESSION["user"]["username"];
-
-	global $qid;
-//	$qid = new PGM_Sql;
 	$qid->Query("
 		UPDATE users
 		SET password = '$newpassword'
 		WHERE username = '$username'
 	");
-//	$qid->close();
 
 	if (has_priv("admin")) {
 		mail(
