@@ -22,6 +22,11 @@
 include ("../application.inc.php");
 require_login();
 
+$qid = new PGM_Sql;
+$qid_order = new PGM_Sql;
+$qid_items = new PGM_Sql;
+$qid_user = new PGM_Sql;
+
 $DOC_TITLE = "Orders_Log_ca";
 include ("$CFG->dirroot" . "/header.php");
 
@@ -50,8 +55,8 @@ function print_order_details($id, $username) {
 	global $page_number;
 //	include ($CFG->globalerror);
 	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
+	global $qid_order, $qid_items, $qid_user;
 
-	$qid_order = new PGM_Sql;
 	$qid_order->Query("
 		SELECT o.*, os.name AS state_name
 		FROM ordersca o, orders_states os
@@ -67,10 +72,8 @@ function print_order_details($id, $username) {
 		$qid_order->next_record();
 	}
 
-	$qid_items = new PGM_Sql;
 	get_order_items(&$qid_items, $id);
 
-	$qid_user = new PGM_Sql;
 	$appoggio = $qid_order->f("username");
 	$qid_user->Query("
 		SELECT usertype, fiscalcode, email
@@ -127,8 +130,8 @@ function print_order_details($id, $username) {
 			"prod_total"		=> $qid_items->f("total"),
 			"prod_ftotal"		=> formatted_price($qid_items->f("total"))
 		));
-		$appoggio = ov($qid_items->f("oiname"));
-		if ($qid_items->f("name") != $appoggio)
+		$appoggio = ($qid_items->f("lname") != "" && $qid_items->f("name") == $qid_items->f("oiname")) ? ov($qid_items->f("lname")) : ov($qid_items->f("oiname"));
+		if ($qid_items->f("name") != $qid_items->f("oiname"))
 			$appoggio = "<div class=\"warning\">" . $appoggio . "</div>";
 		if ($qid_items->f("name") != "")
 			$appoggio = "<a href=\"" . "$CFG->wwwroot" . "/admin/products.php?mode=details&product_id=" . $qid_items->f("product_id") . "\">" . $appoggio . "</a>";
@@ -165,13 +168,13 @@ function print_order_list($username) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-//	global $page_number, $dbchanged;
+//	global $page_number, $datachanged;
 	global $HTTP_GET_VARS;
 //	include ($CFG->globalerror);
 	include ("$CFG->localedir" . $SESSION["lang"] . "/global-names.inc.php");
+	global $qid;
 
-	if (!isset($HTTP_GET_VARS["page_number"]) || $HTTP_GET_VARS["dbchanged"]) {
-		$qid = new PGM_Sql;
+	if (!isset($HTTP_GET_VARS["page_number"]) || $HTTP_GET_VARS["datachanged"]) {
 		$qid->Query("
 			SELECT o.*, os.name AS state_name
 			FROM ordersca o, orders_states os
@@ -181,7 +184,6 @@ function print_order_list($username) {
 
 		$SESSION["numr"] = $qid->num_rows();
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
-//			$qid->seek($i);
 			$qid->next_record();
 			$SESSION["ordersca"][$i]["id"] = $qid->f("id");
 			$SESSION["ordersca"][$i]["date"] = $userday[$qid->f("weekday")] . " " . $qid->f("day") . " " . $usermonth[$qid->f("month")] . " " . $qid->f("year");
